@@ -359,6 +359,7 @@ create_lang_actions (Totem *totem, GtkActionGroup *action_group, guint ui_id,
 
 		add_lang_action (totem, action_group, ui_id, path, prefix,
 				 action_data, i, num + 1, &group);
+		g_free (action_data);
  		i++;
 	}
 
@@ -545,29 +546,11 @@ on_recent_file_item_activated (GtkAction *action,
 {
 	GtkRecentInfo *recent_info;
 	const gchar *uri;
-	gboolean playlist_changed;
-	guint end;
 
 	recent_info = g_object_get_data (G_OBJECT (action), "recent-info");
 	uri = gtk_recent_info_get_uri (recent_info);
 
-	totem_signal_block_by_data (totem->playlist, totem);
-
-	end = totem_playlist_get_last (totem->playlist);
-	playlist_changed = totem_playlist_add_mrl_with_cursor (totem->playlist, uri, NULL);
-	gtk_recent_manager_add_item (totem->recent_manager, uri);
-
-	totem_signal_unblock_by_data (totem->playlist, totem);
-
-	if (playlist_changed)
-	{
-		char *mrl;
-
-		totem_playlist_set_current (totem->playlist, end + 1);
-		mrl = totem_playlist_get_current_mrl (totem->playlist);
-		totem_action_set_mrl_and_play (totem, mrl);
-		g_free (mrl);
-	}
+	totem_add_to_playlist_and_play (totem, uri, NULL, TRUE);
 }
 
 static gint
@@ -597,7 +580,7 @@ totem_compare_recent_items (GtkRecentInfo *a, GtkRecentInfo *b)
 static void
 totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *totem)
 {
-        GList *items, *l;
+        GList *items, *totem_items, *l;
         guint n_items = 0;
 
         if (totem->recent_ui_id != 0) {
@@ -619,10 +602,26 @@ totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *
 
         totem->recent_ui_id = gtk_ui_manager_new_merge_id (totem->ui_manager);
         items = gtk_recent_manager_get_items (recent_manager);
-        items = g_list_sort (items, (GCompareFunc) totem_compare_recent_items);
 
+	/* Remove the non-Totem items */
+	totem_items = NULL;
         for (l = items; l && l->data; l = l->next) {
                 GtkRecentInfo *info;
+
+                info = (GtkRecentInfo *) l->data;
+
+                if (gtk_recent_info_has_group (info, "Totem")) {
+                	gtk_recent_info_ref (info);
+                	totem_items = g_list_prepend (totem_items, info);
+		}
+	}
+	g_list_foreach (items, (GFunc) gtk_recent_info_unref, NULL);
+        g_list_free (items);
+
+        totem_items = g_list_sort (totem_items, (GCompareFunc) totem_compare_recent_items);
+
+        for (l = totem_items; l && l->data; l = l->next) {
+                GtkRecentInfo *info;
                 GtkAction     *action;
                 char           action_name[32];
                 const char    *display_name;
@@ -664,8 +663,8 @@ totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *
                         break;
         }
 
-        g_list_foreach (items, (GFunc) gtk_recent_info_unref, NULL);
-        g_list_free (items);
+        g_list_foreach (totem_items, (GFunc) gtk_recent_info_unref, NULL);
+        g_list_free (totem_items);
 }
 
 void
@@ -1270,7 +1269,7 @@ void
 clear_playlist_action_callback (GtkAction *action, Totem *totem)
 {
 	totem_playlist_clear (totem->playlist);
-	totem_action_set_mrl (totem, NULL);
+	totem_action_set_mrl (totem, NULL, NULL);
 }
 
 static const GtkActionEntry seek_entries_ltr[] = {
