@@ -35,6 +35,7 @@
 #include "totem-private.h"
 
 static GtkFileFilter *filter_all = NULL;
+static GtkFileFilter *filter_subs = NULL;
 static GtkFileFilter *filter_supported = NULL;
 static GtkFileFilter *filter_audio = NULL;
 static GtkFileFilter *filter_video = NULL;
@@ -257,7 +258,8 @@ static const char subtitle_ext[][4] = {
 	"sub",
 	"srt",
 	"smi",
-	"ssa"
+	"ssa",
+	"ass"
 };
 
 static char *
@@ -432,6 +434,18 @@ totem_setup_file_filters (void)
 	gtk_file_filter_add_mime_type (filter_video, "application/x-cd-image");
 	gtk_file_filter_add_mime_type (filter_video, "application/x-cue");
 	g_object_ref (filter_video);
+
+	/* Subtitles files */
+	filter_subs = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter_subs, _("Subtitle files"));
+	gtk_file_filter_add_mime_type (filter_subs, "application/x-subrip"); /* *.srt */
+	gtk_file_filter_add_mime_type (filter_subs, "text/plain"); /* *.asc, *.txt */
+	gtk_file_filter_add_mime_type (filter_subs, "application/x-sami"); /* *.smi, *.sami */
+	gtk_file_filter_add_mime_type (filter_subs, "text/x-microdvd"); /* *.sub */
+	gtk_file_filter_add_mime_type (filter_subs, "text/x-mpsub"); /* *.sub */
+	gtk_file_filter_add_mime_type (filter_subs, "text/x-ssa"); /* *.ssa, *.ass */
+	g_object_ref (filter_subs);
+
 }
 
 void
@@ -487,6 +501,58 @@ totem_add_pictures_dir (GtkWidget *chooser)
 	gtk_file_chooser_add_shortcut_folder (GTK_FILE_CHOOSER (chooser), dir, NULL);
 }
 
+char *
+totem_add_subtitle (GtkWindow *parent, const char *path)
+{
+	GtkWidget *fs;
+	GConfClient *conf;
+	char *new_path;
+	char *subtitle = NULL;
+	gboolean set_folder;
+
+	fs = gtk_file_chooser_dialog_new (_("Select text subtitle"), 
+					  parent,
+					  GTK_FILE_CHOOSER_ACTION_OPEN,
+					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					  GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+					  NULL);
+	gtk_dialog_set_default_response (GTK_DIALOG (fs), GTK_RESPONSE_ACCEPT);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (fs), TRUE);
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (fs), filter_all);
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (fs), filter_subs);
+	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (fs), filter_subs);
+
+	conf = gconf_client_get_default ();
+	set_folder = TRUE;
+	if (path != NULL) {
+		set_folder = gtk_file_chooser_set_current_folder_uri
+			(GTK_FILE_CHOOSER (fs), path);
+	} else {
+		new_path = gconf_client_get_string (conf, "/apps/totem/open_path", NULL);
+		if (new_path != NULL && *new_path != '\0') {
+			set_folder = gtk_file_chooser_set_current_folder_uri
+				(GTK_FILE_CHOOSER (fs), new_path);
+		}
+		g_free (new_path);
+	}
+	
+	if (set_folder == FALSE) {
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fs),
+						     g_get_home_dir ());
+	}
+	totem_add_default_dirs (GTK_FILE_CHOOSER (fs));
+
+	if (gtk_dialog_run (GTK_DIALOG (fs)) == GTK_RESPONSE_ACCEPT) {
+		char *filename;
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (fs));
+		subtitle = g_filename_to_uri (filename, NULL, NULL);
+		g_free(filename);		
+	}
+
+	gtk_widget_destroy (fs);
+	return subtitle;
+}
+
 GSList *
 totem_add_files (GtkWindow *parent, const char *path)
 {
@@ -519,7 +585,7 @@ totem_add_files (GtkWindow *parent, const char *path)
 			(GTK_FILE_CHOOSER (fs), path);
 	} else {
 		new_path = gconf_client_get_string (conf, "/apps/totem/open_path", NULL);
-		if (new_path != NULL && new_path != '\0') {
+		if (new_path != NULL && *new_path != '\0') {
 			set_folder = gtk_file_chooser_set_current_folder_uri
 				(GTK_FILE_CHOOSER (fs), new_path);
 		}
@@ -534,9 +600,6 @@ totem_add_files (GtkWindow *parent, const char *path)
 	totem_add_default_dirs (GTK_FILE_CHOOSER (fs));
 
 	response = gtk_dialog_run (GTK_DIALOG (fs));
-	gtk_widget_hide (fs);
-	while (gtk_events_pending())
-		gtk_main_iteration();
 
 	if (response != GTK_RESPONSE_ACCEPT) {
 		gtk_widget_destroy (fs);
@@ -550,6 +613,7 @@ totem_add_files (GtkWindow *parent, const char *path)
 		g_object_unref (conf);
 		return NULL;
 	}
+	gtk_widget_destroy (fs);
 
 	mrl = filenames->data;
 	if (mrl != NULL) {
@@ -559,7 +623,6 @@ totem_add_files (GtkWindow *parent, const char *path)
 		g_free (new_path);
 	}
 
-	gtk_widget_destroy (fs);
 	g_object_unref (conf);
 
 	return filenames;
